==> ui-18.1.4.tgz: package/components/radio/RadioGroup.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import { isUndefined, nth } from 'lodash';
import React, { useEffect, useState } from 'react';
import { useId } from '@react-devui/hooks';
import { getClassName } from '@react-devui/utils';
import { useGeneralContext, useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate } from '../../utils';
import { DCompose } from '../compose';
import { useFormControl } from '../form';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DRadio } from './Radio';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DRadio.Group' });
export function DRadioGroup(props) {
    var _a, _b;
    const _c = useComponentConfig(COMPONENT_NAME, props), { dFormControl, dList, dModel, dName, dDisabled = false, dType, dSize, dVertical = false, onModelChange } = _c, restProps = __rest(_c, ["dFormControl", "dList", "dModel", "dName", "dDisabled", "dType", "dSize", "dVertical", "onModelChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    const uniqueId = useId();
    const formControlInject = useFormControl(dFormControl);
    const [value, changeValue] = useDValue((_b = (_a = nth(dList, 0)) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : null, dModel, onModelChange, undefined, formControlInject);
    const [isChange, setIsChange] = useState(false);
    // eslint-disable-next-line react-hooks/exhaustive-deps
    useEffect(() => {
        if (isChange) {
            setIsChange(false);
        }
    });
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    return (_jsx(DCompose, Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}radio-group`, {
            [`${dPrefix}radio-group--default`]: isUndefined(dType),
            'is-change': isChange,
        }), dDisabled: disabled, role: "radiogroup", dSize: size, dVertical: dVertical }, { children: dList.map((item) => React.cloneElement(_jsx(DRadio, Object.assign({ dModel: item.value === value, dDisabled: item.disabled, dInputRender: (el) => cloneHTMLElement(el, {
                value: item.value,
                name: dName !== null && dName !== void 0 ? dName : uniqueId,
                ['data-form-item-label-for']: item.value === value,
            }), onModelChange: () => {
                changeValue(item.value);
                setIsChange(true);
            } }, { children: item.label }), item.value), {
            __type: dType,
        })) })));
}

==> ui-18.4.0.tgz: package/components/radio/RadioGroup.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import { isUndefined, nth } from 'lodash';
import React, { useEffect, useState } from 'react';
import { useId } from '@react-devui/hooks';
import { getClassName } from '@react-devui/utils';
import { useGeneralContext, useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate } from '../../utils';
import { DCompose } from '../compose';
import { useFormControl } from '../form';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DRadio } from './Radio';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DRadio.Group' });
export function DRadioGroup(props) {
    var _a, _b;
    const _c = useComponentConfig(COMPONENT_NAME, props), { dFormControl, dList, dModel, dName, dDisabled = false, dType, dSize, dVertical = false, onModelChange } = _c, restProps = __rest(_c, ["dFormControl", "dList", "dModel", "dName", "dDisabled", "dType", "dSize", "dVertical", "onModelChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    const uniqueId = useId();
    const formControlInject = useFormControl(dFormControl);
    const [value, changeValue] = useDValue((_b = (_a = nth(dList, 0)) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : null, dModel, onModelChange, undefined, formControlInject);
    const [isChange, setIsChange] = useState(false);
    // eslint-disable-next-line react-hooks/exhaustive-deps
    useEffect(() => {
        if (isChange) {
            setIsChange(false);
        }
    });
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    return (_jsx(DCompose, Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}radio-group`, {
            [`${dPrefix}radio-group--default`]: isUndefined(dType),
            [`${dPrefix}radio-group--vertical`]: dVertical,
            'is-change': isChange,
        }), dDisabled: disabled, role: "radiogroup", dSize: size, dVertical: dVertical }, { __noStyle: isUndefined(dType) }, { children: dList.map((item) => React.cloneElement(_jsx(DRadio, Object.assign({ dModel: item.value === value, dDisabled: item.disabled, dInputRender: (el) => cloneHTMLElement(el, {
                value: item.value,
                name: dName !== null && dName !== void 0 ? dName : uniqueId,
                ['data-form-item-label-for']: item.value === value,
            }), onModelChange: () => {
                changeValue(item.value);
                setIsChange(true);
            } }, { children: item.label }), item.value), {
            __type: dType,
        })) })));
}
